.. _attributes:

**********
Attributes
**********


Variable Level Attributes
=========================



.. todo::
  Attrs:

  Global Level:

  * Conventions
  * cchdo_software_version
  * cchdo_parameters_version
  * comments
  * featureType

  ACDD Things we want at variable level:

  * creator_name
  * creator_email
  * processing_level
  * instrument
  * instrument_vocabulrary
  * comments (more of them)
  * contributor_name
  * contributor_email
  * contributor_role

  Non ACDD thing var level:
  
  * program_group

  Non ACDD global level?:
  
  * platform (ICES ship code)
  * start/end ports
  * actual start/end dates

  Huge TODO... history at the var and global level, including seperation between metadata and data history.
